'use strict';
module.exports = function(grunt) {
  // Load all tasks
  require('load-grunt-tasks')(grunt);
  // Show elapsed time
  require('time-grunt')(grunt);
  // Require imagemin-mozjpeg
  //var mozjpeg  = require('imagemin-mozjpeg');

  var jsFileList = [
    'assets/vendor/jquery/dist/jquery.min.js',
    'assets/vendor/bootstrap/js/transition.js',
    'assets/vendor/bootstrap/js/alert.js',
    'assets/vendor/bootstrap/js/button.js',
    'assets/vendor/bootstrap/js/carousel.js',
    'assets/vendor/bootstrap/js/collapse.js',
    'assets/vendor/bootstrap/js/dropdown.js',
    'assets/vendor/bootstrap/js/modal.js',
    'assets/vendor/bootstrap/js/tooltip.js',
    'assets/vendor/bootstrap/js/popover.js',
    'assets/vendor/bootstrap/js/scrollspy.js',
    'assets/vendor/bootstrap/js/tab.js',
    'assets/vendor/bootstrap/js/affix.js',
    'assets/js/plugins/*.js',
    'assets/js/_*.js'
  ];

  var htmlFileList = [
    'index.html'
  ];


  grunt.initConfig({
    jshint: {
      options: {
        jshintrc: '.jshintrc'
      },
      all: [
        'Gruntfile.js',
        'assets/js/*.js',
        '!assets/js/scripts.js',
        '!assets/**/*.min.*'
      ]
    },
    less: {
      dev: {
        files: {
          'assets/css/main.css': [
            'assets/less/main.less'
          ]
        },
        options: {
          compress: false,
          ieCompat: true,
          // LESS source map
          // To enable, set sourceMap to true and update sourceMapRootpath based on your install
          sourceMap: true,
          sourceMapFilename: 'assets/css/main.css.map',
          sourceMapRootpath: 'assets/css/'
        }
      },
      build: {
        files: {
          'dist/assets/css/main.min.css': [
            'assets/less/main.less'
          ]
        },
        options: {
          compress: true,
          ieCompat: true
        }
      }
    },
    concat: {
      options: {
        separator: '\n;',
      },
      dist: {
        src: [jsFileList],
        dest: 'assets/js/scripts.js',
      },
    },
    uglify: {
      dist: {
        files: {
          'dist/assets/js/scripts.min.js': [jsFileList]
        }
      }
    },
    autoprefixer: {
      options: {
        browsers: ['last 2 versions', '> 1%', 'ff > 20', 'ie 8', 'ie 9', 'android 2.3', 'android 4', 'opera 12']
      },
      dev: {
        options: {
          map: {
            prev: 'assets/css/'
          }
        },
        src: 'assets/css/main.css'
      },
      build: {
        src: 'dist/assets/css/main.min.css'
      }
    },
    processhtml: {
      build: {
        files: {
          'dist/index.html': ['index.html']
        }
      }
    },
    uncss: {
      options: {
        compress: true,
        report: 'min',
        //ignoreSheets : [/googleapis/,/font-awesome/],
        ignore: [
          /\w\.in/,
          ".fade",
          ".collapse",
          ".collapsing",
          /(#|\.)left/,
          /(#|\.)active/,
          /(#|\.)next/,
          /(#|\.)navbar(\-[a-zA-Z]+)?/,
          /(#|\.)dropdown(\-[a-zA-Z]+)?/,
          /(#|\.)(open)/,
        ]
      },
      build: {
        files: {
          'dist/assets/css/main.min.css': ['dist/index.html']
        }
      }
    },
    copy:{
      build: {
        files: [
          {expand: true, cwd: '', src: 'favicon.ico', dest: 'dist/', flatten: true, filter: 'isFile'},
          {expand: true, cwd: 'assets/vendor/font-awesome/fonts/', src: ['**'], dest: 'dist/assets/fonts/', flatten: true, filter: 'isFile'},
        ]
      }
    },
    imagemin: {
      dynamic: {
          options: {
              optimizationLevel: 4,
              svgoPlugins: [{ removeViewBox: false }],
              progressive: true//,
              //use: [mozjpeg({quality: 80})]
          },
          files: [{
              expand: true,
              cwd: 'assets/img',
              src: ['**/*.{png,jpg,gif,svg}'],
              dest: 'dist/assets/img'
          }]
      },
    },
    cssmin: {
      minify: {
        files: {
          'dist/assets/css/main.min.css': ['dist/assets/css/main.min.css']
        }
      }
    },
    usebanner: {
      dist: {
        options: {
          position: 'top',
          banner: '/*** \n*\n' +
                  ' * $$\\                                                             $$\\ $$\\  \n' + 
                  ' * $$ |                                                            $$ |$$ | \n' + 
                  ' * $$$$$$$\\  $$\\   $$\\ $$$$$$$$\\ $$$$$$$$\\ $$\\  $$\\  $$\\  $$$$$$\\  $$ |$$ | \n' + 
                  ' * $$  __$$\\ $$ |  $$ |\\____$$  |\\____$$  |$$ | $$ | $$ | \\____$$\\ $$ |$$ | \n' + 
                  ' * $$ |  $$ |$$ |  $$ |  $$$$ _/   $$$$ _/ $$ | $$ | $$ | $$$$$$$ |$$ |$$ | \n' + 
                  ' * $$ |  $$ |$$ |  $$ | $$  _/    $$  _/   $$ | $$ | $$ |$$  __$$ |$$ |$$ | \n' + 
                  ' * $$$$$$$  |\\$$$$$$  |$$$$$$$$\\ $$$$$$$$\\ \\$$$$$\\$$$$  |\\$$$$$$$ |$$ |$$ | \n' + 
                  ' * \\_______/  \\______/ \\________|\\________| \\_____\\____/  \\_______|\\__|\\__| \n*\n' + 
                  ' * -- File generated on <%= grunt.template.today("dd-mm-yyyy HH:MM:ss") %> -- \n*\n ***/'
        },
        files: {
          src: [ 'dist/assets/css/main.min.css', 'dist/assets/js/scripts.min.js' ]
        }
      }
    },
    watch: {
      less: {
        files: [
          'assets/less/*.less',
          'assets/less/**/*.less'
        ],
        tasks: ['less:dev', 'autoprefixer:dev']
      },
      js: {
        files: [
          jsFileList,
          '<%= jshint.all %>'
        ],
        tasks: ['jshint', 'concat']
      }
    }
  });

  // Register tasks
  grunt.registerTask('default', [
    'dev'
  ]);
  grunt.registerTask('dev', [
    'jshint',
    'less:dev',
    'autoprefixer:dev',
    'concat'
  ]);
  grunt.registerTask('build', [
    'jshint',
    'less:build',
    'autoprefixer:build',
    'uglify',
    'processhtml',
    'uncss',
    'copy:build',
    'imagemin',
    'cssmin',
    'usebanner'
  ]);
};
